Learn R Programming

phonics (version 1.4.0)

phonics-package: Phonetic spelling algorithms

Description

The phonics package provides phonetic encoders for English, German, and French names, together with Match Rating Approach comparison and a convenience dispatcher. See phonics for the complete method list and vignette("phonics") for an overview.

Arguments

Author

Maintainer: James Howard jh@jameshoward.us (ORCID)

Authors:

Other contributors:

  • Kyle Haynes [contributor]

  • Amanda Hood [contributor]

  • Os Keyes [contributor]

References

Howard, J. P., II (2020). "Phonetic Spelling Algorithm Implementations for R." Journal of Statistical Software, 95(8), 1--21. tools:::Rd_expr_doi("10.18637/jss.v095.i08").

See Also