Learn R Programming

phonics (version 1.4.0)

rogerroot: Roger Root Name Coding Procedure

Description

Provides the Roger Root name coding system

Usage

rogerroot(word, maxCodeLen = 5, clean = TRUE)

Value

the Roger Root encoded character vector

Arguments

word

string or vector of strings to encode

maxCodeLen

maximum length of the resulting encodings, in characters

clean

if TRUE, return NA for unknown alphabetical characters

Details

The rogerroot function phonetically encodes the given string using the Roger Root algorithm. The variable word is a string or vector of strings to encode.

The variable maxCodeLen is the limit on how long the returned code should be. The default is 5.

The rogerroot algorithm is only defined for inputs over the standard English alphabet, i.e., "A-Z.". Non-alphabetical characters are removed from the string in a locale-dependent fashion. This strips spaces, hyphens, and numbers. Other letters, such as "Ü," may be permissible in the current locale but are unknown to rogerroot. For inputs outside of its known range, the output is undefined and NA is returned and a warning this thrown. If clean is FALSE, rogerroot attempts to process the strings. The default is TRUE.

References

James P. Howard, II, "Phonetic Spelling Algorithm Implementations for R," Journal of Statistical Software, vol. 95, no. 8, (2020), p. 1--21, <10.18637/jss.v095.i08>.

Billy T. Lynch and William L. Arends, Selection of a Surname Coding Procedure for the SRS Record Linkage System, United States Department of Agriculture, 1977, Appendix B.

See Also

Other phonics: caverphone(), cologne(), lein(), metaphone(), mra_encode(), nysiis(), onca(), phonex(), phonics(), soundex(), statcan()

Examples

Run this code
rogerroot("William")
rogerroot(c("Peter", "Peady"))
rogerroot("Stevenson")

Run the code above in your browser using DataLab