The Oxford Name Compression Algorithm name coding procedure
onca(word, maxCodeLen = 4, clean = TRUE, modified = FALSE, refined = FALSE)the ONCA encoded character vector
string or vector of strings to encode
maximum length of the resulting encodings, in characters
if TRUE, return NA for unknown alphabetical characters
if TRUE, use the modified nysiis function
if TRUE, use the refinedSoundex function
The variable word is the name to be encoded. The variable
maxCodeLen is the limit on how long the returned name code
should be. The default is 4.
The onca algorithm is only defined for inputs over the
standard English alphabet, i.e., "A-Z.". Non-alphabetical
characters are removed from the string in a locale-dependent fashion.
This strips spaces, hyphens, and numbers. Other letters, such as
"Ü," may be permissible in the current locale but are unknown to
onca. For inputs outside of its known range, the output is
undefined and NA is returned and a warning this thrown.
If clean is FALSE, onca attempts to process the
strings. The default is TRUE.
Gill, Leicester. "OX-LINK: the Oxford medical record linkage system." (1997).
James P. Howard, II, "Phonetic Spelling Algorithm Implementations for R," Journal of Statistical Software, vol. 25, no. 8, (2020), p. 1--21, <10.18637/jss.v095.i08>.
Other phonics:
caverphone(),
cologne(),
lein(),
metaphone(),
mra_encode(),
nysiis(),
phonex(),
phonics(),
rogerroot(),
soundex(),
statcan()
onca("William")
onca(c("Peter", "Peady"))
onca("Stevenson", maxCodeLen = 8)
Run the code above in your browser using DataLab